@@ -8,9 +8,9 @@ use Log::ger;
 use App::BrowserUtils ();
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-24'; # DATE
+our $DATE = '2022-10-07'; # DATE
 our $DIST = 'App-VivaldiUtils'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 our %SPEC;
 
@@ -159,7 +159,7 @@ App::VivaldiUtils - Utilities related to the Vivaldi browser
 
 =head1 VERSION
 
-This document describes version 0.009 of App::VivaldiUtils (from Perl distribution App-VivaldiUtils), released on 2022-07-24.
+This document describes version 0.010 of App::VivaldiUtils (from Perl distribution App-VivaldiUtils), released on 2022-10-07.
 
 =head1 SYNOPSIS
 
@@ -381,6 +381,8 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<signal> => I<unix::signal>
+
 =item * B<users> => I<array[unix::uid::exists]>
 
 Kill browser processes that belong to certain user(s) only.
@@ -561,6 +563,8 @@ Source repository is at L<https://github.com/perlancar/perl-App-VivaldiUtils>.
 Some other CLI utilities related to Vivaldi: L<dump-vivaldi-history> (from
 L<App::DumpVivaldiHistory>).
 
+L<App::BraveUtils>
+
 L<App::OperaUtils>
 
 L<App::FirefoxUtils>
@@ -586,9 +590,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
